#include <stdio.h>
#include <stdlib.h>
#include "plot.h"

void plot(char *filename, double *poly, int deg, double a, double b) {
	printf("Zapisuje wykres w pliku: %s -- format Asymptote\n",filename);

	FILE *plot = fopen(filename,"w");

	if(plot==NULL) {
		printf("Problem z otwarciem pliku: %s do zapisu!\n",filename);
		exit(-1);
	}

	fprintf(plot,"import graph;\n");
	fprintf(plot,"real a=%lf; real b=%lf;\n",a,b);

	fprintf(plot,
		"size(6cm,6cm,IgnoreAspect);\n"
		"real f(real x) {return exp(x+x)+1;}\n"
		"real w(real x) {"
		"return(");
	for(int i=deg-1;i>=0;i--) {
		if(poly[i]!=0.0)
			fprintf(plot,"%+.20f*x^%d",poly[i],i);
	}
		
		fprintf(plot,");}\n"

		"pair F(real x) {return (x,f(x)+1);}\n"
		"pair W(real x) {return (x,w(x)-1);}\n"

		"draw(graph(f,a,b,operator ..),red);\n"
		"draw(graph(w,a,b,operator ..),blue);\n"

		"label(\"$y=e^{2x}+1$\",F(b),SE,red);\n"
		"label(\"$y=W(x)$\",W(b),SE,blue);\n"

		"xaxis(\"$x$\",fontsize(6),LeftTicks,EndArrow);\n"
		"yaxis(\"$y$\",0-0.5*f(a),fontsize(6),RightTicks,EndArrow);\n");
	fclose(plot);
}

void plotTeX(char *filename, double *poly, int deg, double a, double b) {
	printf("Zapisuje wykres w pliku: %s -- format LaTeX + Asymptote\n",filename);

	FILE *plot = fopen(filename,"w");

	if(plot==NULL) {
		printf("Problem z otwarciem pliku: %s do zapisu!\n",filename);
		exit(-1);
	}

	fprintf(plot,
"\\documentclass[12pt]{article}\n"
"\\usepackage{polski}\n"
"\\usepackage[cp1250]{inputenc}\n"
"\\usepackage{amsmath,amsfonts,amssymb}\n"
"\\usepackage[inline]{asymptote}\n"
"\\begin{document}\n"
"\\thispagestyle{empty}\n"
"\\noindent {\\bf Funkcja} $f\\colon [%.1lf,%.1lf]\\to\\mathbb{R}$ dana wzorem:\n"
"$$f(x) = e^{2x} + 1.$$\n"
"{\\bf Wielomian interpolacyjny}\\footnote{Aby poprawi czytelno, wspczynniki wielomianu s wypisywane z dokadnoci do 4 miejsc po przecinku.}:\n"
"$$W(x) = ",a,b);
	
	for(int i=deg-1;i>=0;i--) {
		if(poly[i]!=0.0)
			fprintf(plot,"%+.4lf\\cdot x^{%d}",poly[i],i);
		if(i%4==0) fprintf(plot,"$$\n$$");
		}
	

fprintf(plot,"$$\n"
"{\\bf Wykres:}\n"
"\\begin{center}\n"
"\\begin{asy}[10cm,10cm,IgnoreAspect]\n");

	fprintf(plot,"import graph;\n");
	fprintf(plot,"real a=%lf; real b=%lf;\n",a,b);

	fprintf(plot,
		"real f(real x) {return exp(x+x)+1;}\n"
		"real w(real x) {"
		"return(");

	for(int i=deg-1;i>=0;i--) {
		if(poly[i]!=0.0)
			fprintf(plot,"%+.20lf*x^%d",poly[i],i);
	}
		fprintf(plot,");}\n"

		"pair F(real x) {return (x,f(x));}\n"
		"pair W(real x) {if(f(x)-w(x)<5) return (x,w(x)-5); else return(x,w(x)-1);}\n"

		"draw(graph(f,a,b,operator ..),red);\n"
		"draw(graph(w,a,b,operator ..),blue);\n"

		"label(\"$y=e^{2x}+1$\",F(b),SE,red);\n"
		"label(\"$y=W(x)$\",W(b),SE,blue);\n"

		"xaxis(\"$x$\",fontsize(6),LeftTicks,EndArrow);\n"
		"yaxis(\"$y$\",0-0.5f(a),fontsize(6),RightTicks,EndArrow);\n");

	fprintf(plot,
"\\end{asy}\n"
"\\end{center}\n"
"\\end{document}\n");

	fclose(plot);
}
